@@ -4,14 +4,11 @@ use base qw( Plagger::Plugin );
 
 use Feed::Find;
 use Plagger::Enclosure;
+use Plagger::FeedParser;
 use Plagger::UserAgent;
 use List::Util qw(first);
 use UNIVERSAL::require;
 use URI;
-use XML::Feed;
-use XML::Feed::RSS;
-
-$XML::Feed::RSS::PREFERRED_PARSER = first { $_->require } qw( XML::RSS::Liberal XML::RSS::LibXML XML::RSS );
 
 sub register {
     my($self, $context) = @_;
@@ -33,29 +30,19 @@ sub aggregate {
 
     $content_type =~ s/;.*$//; # strip charset= cruft
 
-    my $content = $res->content;
-    if ( $Feed::Find::IsFeed{$content_type} || $self->looks_like_feed(\$content) ) {
-        $self->handle_feed($url, \$content, $args->{feed});
+    my $feed_url = Plagger::FeedParser->discover($res);
+    if ($url eq $feed_url) {
+        $self->handle_feed($url, \$res->content, $args->{feed});
+    } elsif ($feed_url) {
+        $res = $self->fetch_content($feed_url) or return;
+        $self->handle_feed($feed_url, \$res->content, $args->{feed});
     } else {
-        $content = Plagger::Util::decode_content($res);
-        my @feeds = Feed::Find->find_in_html(\$content, $url);
-        if (@feeds) {
-            $url = $feeds[0];
-            $res = $self->fetch_content($url) or return;
-            $self->handle_feed($url, \$res->content, $args->{feed});
-        } else {
-            return;
-        }
+        return;
     }
 
     return 1;
 }
 
-sub looks_like_feed {
-    my($self, $content_ref) = @_;
-    $$content_ref =~ m!<rss |<rdf:RDF\s+.*?xmlns="http://purl\.org/rss|<feed\s+xmlns="!s;
-}
-
 sub fetch_content {
     my($self, $url) = @_;
 
@@ -87,19 +74,9 @@ sub handle_feed {
     my $args = { content => $$xml_ref };
     $context->run_hook('aggregator.filter.feed', $args);
 
-    # override XML::LibXML with Liberal
-    my $sweeper; # XML::Liberal >= 0.13
-
-    eval { require XML::Liberal };
-    if (!$@ && $XML::Liberal::VERSION >= 0.10) {
-        $sweeper = XML::Liberal->globally_override('LibXML');
-    }
-
-    local $XML::Atom::ForceUnicode = 1;
-    my $remote = eval { XML::Feed->parse(\$args->{content}) };
-
-    unless ($remote) {
-        $context->log(error => "Parsing $url failed. " . ($@ || XML::Feed->errstr));
+    my $remote = eval { Plagger::FeedParser->parse(\$args->{content}) };
+    if ($@) {
+        $context->log(error => "Parser $url failed: $@");
         return;
     }
 
@@ -111,6 +88,8 @@ sub handle_feed {
     $feed->language($remote->language);
     $feed->author(_u($remote->author));
     $feed->updated($remote->modified);
+
+    Encode::_utf8_on($$xml_ref);
     $feed->source_xml($$xml_ref);
 
     if ($remote->format eq 'Atom') {
@@ -118,7 +97,7 @@ sub handle_feed {
     }
 
     if ($remote->format =~ /^RSS/) {
-        $feed->image( $remote->{rss}->image )
+        $feed->image( \%{$remote->{rss}->image} )
             if $remote->{rss}->image;
     } elsif ($remote->format eq 'Atom') {
         $feed->image({ url => $remote->{atom}->logo })
@@ -180,6 +159,11 @@ sub handle_feed {
             }
         }
 
+        # entry image support
+        if ($remote->format =~ /^RSS / and my $img = $e->{entry}->{image}) {
+            $entry->icon(\%$img);
+        }
+
         # TODO: move MediaRSS, Hatena, iTunes and those specific parser to be subclassed
 
         # Media RSS
