@@ -27,7 +27,7 @@ sub feed {
     $self->{entries} = {};
 
     if ($args->{feed}->count == 0) {
-        $context->log(debug => "Deleting " . $args->{feed}->url . " since it has 0 entries");
+        $context->log(debug => "Deleting " . $args->{feed}->title . " since it has 0 entries");
         $context->update->delete_feed($args->{feed})
     }
 
