@@ -8,17 +8,17 @@ sub load {
     my($self, $context) = @_;
 
     my $plist = Mac::Tie::PList->new_from_file($self->conf->{path});
-    $self->find_feed($context, $plist, []);
+    $self->find_feed($context, $plist);
 }
 
 sub find_feed {
-    my($self, $context, $plist, $tags) = @_;
+    my($self, $context, $plist, @tags) = @_;
 
-    if(my @children = @{$plist->{Children}}) {
-	push(@$tags, $plist->{Title}) if $plist->{Title};
+    if($plist->{Children}) {
+	push(@tags, $plist->{Title}) if $plist->{Title};
 
-	for my $child (@children) {
-	    $self->find_feed($context, $child, $tags);
+	for my $child (@{$plist->{Children}}) {
+	    $self->find_feed($context, $child, @tags);
 	}
     } elsif($plist->{URLString}) {
 	my $url = new URI($plist->{URLString});
@@ -34,7 +34,7 @@ sub find_feed {
 	my $feed = Plagger::Feed->new;
 	$feed->url($url->as_string);
 	$feed->title($plist->{URIDictionary}->{title});
-	$feed->tags($tags);
+	$feed->tags(\@tags);
 	$context->subscription->add($feed);
     }
 }
