@@ -6,7 +6,12 @@ use File::Temp qw(tempdir);
 use LWP::Simple;
 use YAML;
 
+our $lockdir = "$ENV{HOME}/.plagger-smoke.lock";
+mkdir $lockdir, 0777 or die "Other process is running!\n";
+our $run  = 1;
+
 our $repo = "http://svn.bulknews.net/repos/plagger";
+our $trac = "http://plagger.org/trac";
 our $file = "$ENV{HOME}/.plagger-smoke.yml";
 
 my $config  = eval { YAML::LoadFile($file) } || {};
@@ -16,15 +21,18 @@ $config->{revision} ||= $current - 1;
 
 my $run;
 while (++$config->{revision} <= $current) {
-    run_chimps($config->{revision});
+    my $branch = get_branch($config->{revision});
+    run_chimps($config->{revision}, $branch);
     $run++;
 }
 
 $config->{revision} = $current;
 YAML::DumpFile($file, $config) if $run;
 
+END { rmdir $lockdir if $run && -e $lockdir };
+
 sub run_chimps {
-    my $revision = shift;
+    my($revision, $branch) = @_;
 
     my $workdir  = tempdir(CLEANUP => 1);
     my $checkout = "plagger-r$revision";
@@ -35,8 +43,10 @@ sub run_chimps {
         die "$workdir/$checkout exists. Remove it first";
     }
 
+    warn "Testing r$revision on $branch\n";
+
     delete $ENV{LANG}; # svn doesn't grok LANG=ja_JP.UTF-8
-    system("svn co -r $revision $repo/trunk/plagger $checkout");
+    system("svn co -r $revision $repo/$branch/plagger $checkout");
     chdir $checkout;
 
     system("perl Makefile.PL --skip");
@@ -55,3 +65,10 @@ sub get_current {
     $html =~ /Revision (\d+):/ and return $1;
     return;
 }
+
+sub get_branch {
+    my $revision = shift;
+    my $diff = LWP::Simple::get("$trac/changeset/$revision?format=diff");
+    $diff =~ m!^Index: (branches/[^/]+|trunk)/! or return $1;
+    return "trunk";
+}
